import { LockPerson } from "@mui/icons-material";
import { Button } from "@mui/material";

const AnswerBox = ({ title, number = 0 }) => {
  return (
    <div className="flex items-center flex-col justify-between max-h-8  text-text-second text-xs">
      <p className="text-xs whitespace-nowrap">{title}</p>
      <p>{number}</p>
    </div>
  );
};

const ExamCard = ({
  exam,
  testResult,
  locked,
  fullWidth = false,
  shadow = false,
  handleOpen,
  onClick,
}) => {
  return (
    <div
      className={`w-full relative  ${
        !fullWidth && " max-w-[294px]"
      } h-full min-h-[105px] max-h-[105px] px-4 py-3 rounded-lg ${
        shadow && "shadow-base"
      }`}
    >
      {locked && (
        <div className="absolute inset-0 bg-background-disable z-20 rounded-lg bg-opacity-65 px-4 py-3 flex justify-end">
          <div className="w-10 h-10 rounded-lg bg-background-white flex items-center justify-center shadow-base">
            <LockPerson color="secondary" fontSize="medium" />
          </div>
        </div>
      )}
      <div className="w-full  h-full flex justify-between">
        {/* right side position */}
        <div className="h-full flex flex-col justify-between ">
          <strong>آزمون آیین نامه شماره 4</strong>
          <div className="flex items-center justify-between">
            <AnswerBox title={"درست"} />
            <AnswerBox title={"غلط"} />
            <AnswerBox title={"بی پاسخ"} />
          </div>
        </div>
        {/* left side position */}
        <div className="h-full flex flex-col-reverse justify-between items-end">
          <Button
            variant="outlined"
            color="secondary"
            disabled={locked}
            onClick={onClick}
          >
            شرکت در آزمون
          </Button>
          {testResult && (
            <div
              className={`px-2 h-[22px] rounded-lg flex items-center ${
                testResult === "passed"
                  ? "bg-background-success"
                  : "bg-background-error"
              }`}
            >
              <p
                className={`${
                  testResult === "passed" ? "text-text-green" : "text-text-red"
                }`}
              >
                {testResult === "passed" ? "قبول" : "مردود"}
              </p>
            </div>
          )}
        </div>
      </div>
    </div>
  );
};

export default ExamCard;
